@@ -2,8 +2,6 @@
 
 #include <bindrcpp.h>
 
-#include <plogr.h>
-
 #include <algorithm>
 #include <string>
 
@@ -12,10 +10,11 @@ using namespace Rcpp;
 using namespace bindrcpp;
 
 // [[Rcpp::export(rng = FALSE)]]
-SEXP callback_string_typed(Symbol name, bindrcpp::GETTER_FUNC_STRING_TYPED fun, bindrcpp::PAYLOAD payload) {
-  LOG_VERBOSE << type2name(name);
-  LOG_VERBOSE << payload.p;
-
+SEXP callback_string_typed(
+  Symbol name,
+  bindrcpp::GETTER_FUNC_STRING_TYPED fun,
+  bindrcpp::PAYLOAD payload
+) {
   String name_string = name.c_str();
   name_string.set_encoding(CE_NATIVE);
 
@@ -23,17 +22,20 @@ SEXP callback_string_typed(Symbol name, bindrcpp::GETTER_FUNC_STRING_TYPED fun,
 }
 
 // [[Rcpp::export(rng = FALSE)]]
-SEXP callback_symbol_typed(Symbol name, bindrcpp::GETTER_FUNC_SYMBOL_TYPED fun, bindrcpp::PAYLOAD payload) {
-  LOG_VERBOSE << type2name(name);
-  LOG_VERBOSE << payload.p;
-
+SEXP callback_symbol_typed(
+  Symbol name,
+  bindrcpp::GETTER_FUNC_SYMBOL_TYPED fun,
+  bindrcpp::PAYLOAD payload
+) {
   return fun(name, payload);
 }
 
 // [[Rcpp::export(rng = FALSE)]]
-SEXP callback_string_wrapped(Symbol name, bindrcpp::GETTER_FUNC_STRING_WRAPPED fun, List payload) {
-  LOG_VERBOSE << type2name(name);
-
+SEXP callback_string_wrapped(
+  Symbol name,
+  bindrcpp::GETTER_FUNC_STRING_WRAPPED fun,
+  List payload
+) {
   String name_string = name.c_str();
   name_string.set_encoding(CE_NATIVE);
 
@@ -41,9 +43,11 @@ SEXP callback_string_wrapped(Symbol name, bindrcpp::GETTER_FUNC_STRING_WRAPPED f
 }
 
 // [[Rcpp::export(rng = FALSE)]]
-SEXP callback_symbol_wrapped(Symbol name, bindrcpp::GETTER_FUNC_SYMBOL_WRAPPED fun, List payload) {
-  LOG_VERBOSE << type2name(name);
-
+SEXP callback_symbol_wrapped(
+  Symbol name,
+  bindrcpp::GETTER_FUNC_SYMBOL_WRAPPED fun,
+  List payload
+) {
   return fun(name, payload);
 }
 
@@ -52,55 +56,75 @@ class CallbackTester {
   const int magic;
 
 public:
-  CallbackTester() : magic(MAGIC) { LOG_VERBOSE; }
-  ~CallbackTester() { LOG_VERBOSE; }
+  CallbackTester() : magic(MAGIC) {}
+  ~CallbackTester() {}
 
   static SEXP tolower_static(const Rcpp::String& name, List payload) {
     XPtr<CallbackTester> p = payload[0];
     CallbackTester* this_ = p.get();
-    LOG_VERBOSE << this_;
     return this_->tolower(name);
   }
 
   static SEXP toupper_static(const Rcpp::String& name, List payload) {
     XPtr<CallbackTester> p = payload[0];
     CallbackTester* this_ = p.get();
-    LOG_VERBOSE << this_;
     return this_->toupper(name);
   }
 
 private:
   SEXP tolower(Rcpp::String name) {
-    LOG_VERBOSE << magic;
-    if (magic != MAGIC)
+    if (magic != MAGIC) {
       stop("payload lost");
+    }
     std::string name_string = name;
-    std::transform(name_string.begin(), name_string.end(), name_string.begin(), ::tolower);
+    std::transform(
+      name_string.begin(),
+      name_string.end(),
+      name_string.begin(),
+      ::tolower
+    );
     return CharacterVector(name_string);
   }
 
   SEXP toupper(Rcpp::String name) {
-    LOG_VERBOSE << magic;
-    if (magic != MAGIC)
+    if (magic != MAGIC) {
       stop("payload lost");
+    }
     std::string name_string = name;
-    std::transform(name_string.begin(), name_string.end(), name_string.begin(), ::toupper);
+    std::transform(
+      name_string.begin(),
+      name_string.end(),
+      name_string.begin(),
+      ::toupper
+    );
     return CharacterVector(name_string);
   }
 };
 
 // [[Rcpp::export]]
-Environment do_test_create_environment(CharacterVector names, String xform, Environment parent) {
-  List payload = List::create(_["callback"] = XPtr<CallbackTester>(new CallbackTester));
+Environment do_test_create_environment(
+  CharacterVector names,
+  String xform,
+  Environment parent
+) {
+  List payload =
+    List::create(_["callback"] = XPtr<CallbackTester>(new CallbackTester));
 
   if (xform == "tolower") {
     return bindrcpp::create_env_string_wrapped(
-      names, &CallbackTester::tolower_static, payload, parent);
-  }
-  else if (xform == "toupper") {
+      names,
+      &CallbackTester::tolower_static,
+      payload,
+      parent
+    );
+  } else if (xform == "toupper") {
     return bindrcpp::create_env_string_wrapped(
-      names, &CallbackTester::toupper_static, payload, parent);
-  }
-  else
+      names,
+      &CallbackTester::toupper_static,
+      payload,
+      parent
+    );
+  } else {
     stop("unknown xform");
+  }
 }
